drop table if exists publication;
drop table if exists post;
drop table if exists author;
drop type if exists author_role;

create type author_role as enum ('READER', 'WRITER', 'ADMIN');

create table author
(
    id              uuid        default gen_random_uuid() primary key,
    name            varchar(255) unique        not null,
    password        text                       not null,
    profile_picture bytea,
    role            author_role default 'READER' not null
);

create table post
(
    id               serial primary key,
    description      varchar(512) not null,
    illustration     bytea,
    title            varchar(50)  not null,
    body             text         not null,
    category         varchar(50)  not null,
    publication_date date         not null
);

create table publication
(
    author_fk uuid,
    post_fk   serial,
    foreign key (author_fk) references author (id),
    foreign key (post_fk) references post (id)
);
